@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -36,7 +36,8 @@ class CrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ApplyBlackList", params)
+            headers = request.headers
+            body = self.call("ApplyBlackList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ApplyBlackListResponse()
@@ -54,6 +55,35 @@ class CrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ApplyBlackListData(self, request):
+        """提交机器人黑名单申请
+
+        :param request: Request instance for ApplyBlackListData.
+        :type request: :class:`tencentcloud.cr.v20180321.models.ApplyBlackListDataRequest`
+        :rtype: :class:`tencentcloud.cr.v20180321.models.ApplyBlackListDataResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ApplyBlackListData", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ApplyBlackListDataResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ApplyCreditAudit(self, request):
         """提交信审外呼申请，返回当次请求日期。
 
@@ -64,7 +94,8 @@ class CrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ApplyCreditAudit", params)
+            headers = request.headers
+            body = self.call("ApplyCreditAudit", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ApplyCreditAuditResponse()
@@ -82,6 +113,64 @@ class CrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ChangeBotCallStatus(self, request):
+        """更新机器人任务作业状态
+
+        :param request: Request instance for ChangeBotCallStatus.
+        :type request: :class:`tencentcloud.cr.v20180321.models.ChangeBotCallStatusRequest`
+        :rtype: :class:`tencentcloud.cr.v20180321.models.ChangeBotCallStatusResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ChangeBotCallStatus", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ChangeBotCallStatusResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def ChangeBotTaskStatus(self, request):
+        """更新机器人任务状态
+
+        :param request: Request instance for ChangeBotTaskStatus.
+        :type request: :class:`tencentcloud.cr.v20180321.models.ChangeBotTaskStatusRequest`
+        :rtype: :class:`tencentcloud.cr.v20180321.models.ChangeBotTaskStatusResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ChangeBotTaskStatus", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ChangeBotTaskStatusResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateBotTask(self, request):
         """创建机器人任务
 
@@ -92,7 +181,8 @@ class CrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateBotTask", params)
+            headers = request.headers
+            body = self.call("CreateBotTask", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateBotTaskResponse()
@@ -120,7 +210,8 @@ class CrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeBotFlow", params)
+            headers = request.headers
+            body = self.call("DescribeBotFlow", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeBotFlowResponse()
@@ -148,7 +239,8 @@ class CrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeCreditResult", params)
+            headers = request.headers
+            body = self.call("DescribeCreditResult", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeCreditResultResponse()
@@ -176,7 +268,8 @@ class CrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeFileModel", params)
+            headers = request.headers
+            body = self.call("DescribeFileModel", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeFileModelResponse()
@@ -204,7 +297,8 @@ class CrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeRecords", params)
+            headers = request.headers
+            body = self.call("DescribeRecords", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeRecordsResponse()
@@ -232,7 +326,8 @@ class CrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTaskStatus", params)
+            headers = request.headers
+            body = self.call("DescribeTaskStatus", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTaskStatusResponse()
@@ -260,7 +355,8 @@ class CrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DownloadBotRecord", params)
+            headers = request.headers
+            body = self.call("DownloadBotRecord", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DownloadBotRecordResponse()
@@ -288,7 +384,8 @@ class CrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DownloadDialogueText", params)
+            headers = request.headers
+            body = self.call("DownloadDialogueText", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DownloadDialogueTextResponse()
@@ -317,7 +414,8 @@ class CrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DownloadRecordList", params)
+            headers = request.headers
+            body = self.call("DownloadRecordList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DownloadRecordListResponse()
@@ -345,7 +443,8 @@ class CrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DownloadReport", params)
+            headers = request.headers
+            body = self.call("DownloadReport", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DownloadReportResponse()
@@ -373,7 +472,8 @@ class CrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ExportBotData", params)
+            headers = request.headers
+            body = self.call("ExportBotData", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ExportBotDataResponse()
@@ -391,6 +491,35 @@ class CrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def QueryBlackListData(self, request):
+        """查看黑名单数据列表
+
+        :param request: Request instance for QueryBlackListData.
+        :type request: :class:`tencentcloud.cr.v20180321.models.QueryBlackListDataRequest`
+        :rtype: :class:`tencentcloud.cr.v20180321.models.QueryBlackListDataResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("QueryBlackListData", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.QueryBlackListDataResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def QueryBotList(self, request):
         """查询机器人任务状态列表
 
@@ -401,7 +530,8 @@ class CrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("QueryBotList", params)
+            headers = request.headers
+            body = self.call("QueryBotList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.QueryBotListResponse()
@@ -419,6 +549,35 @@ class CrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def QueryCallList(self, request):
+        """机器人任务查询
+
+        :param request: Request instance for QueryCallList.
+        :type request: :class:`tencentcloud.cr.v20180321.models.QueryCallListRequest`
+        :rtype: :class:`tencentcloud.cr.v20180321.models.QueryCallListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("QueryCallList", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.QueryCallListResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def QueryInstantData(self, request):
         """实时数据查询
 
@@ -429,7 +588,8 @@ class CrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("QueryInstantData", params)
+            headers = request.headers
+            body = self.call("QueryInstantData", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.QueryInstantDataResponse()
@@ -457,7 +617,8 @@ class CrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("QueryProducts", params)
+            headers = request.headers
+            body = self.call("QueryProducts", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.QueryProductsResponse()
@@ -485,7 +646,8 @@ class CrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("QueryRecordList", params)
+            headers = request.headers
+            body = self.call("QueryRecordList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.QueryRecordListResponse()
@@ -503,6 +665,35 @@ class CrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def UpdateBotTask(self, request):
+        """更新机器人任务
+
+        :param request: Request instance for UpdateBotTask.
+        :type request: :class:`tencentcloud.cr.v20180321.models.UpdateBotTaskRequest`
+        :rtype: :class:`tencentcloud.cr.v20180321.models.UpdateBotTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UpdateBotTask", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.UpdateBotTaskResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def UploadBotData(self, request):
         """上传机器人任务数据
 
@@ -513,7 +704,8 @@ class CrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UploadBotData", params)
+            headers = request.headers
+            body = self.call("UploadBotData", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UploadBotDataResponse()
@@ -541,7 +733,8 @@ class CrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UploadBotFile", params)
+            headers = request.headers
+            body = self.call("UploadBotFile", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UploadBotFileResponse()
@@ -570,7 +763,8 @@ class CrClient(AbstractClient):
         try:
             params = request._serialize()
             options = {'IsMultipart': True, 'BinaryParams': [u'File']}
-            body = self.call("UploadDataFile", params, options=options)
+            headers = request.headers
+            body = self.call("UploadDataFile", params, options=options, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UploadDataFileResponse()
@@ -598,7 +792,8 @@ class CrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UploadDataJson", params)
+            headers = request.headers
+            body = self.call("UploadDataJson", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UploadDataJsonResponse()
@@ -626,7 +821,8 @@ class CrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UploadFile", params)
+            headers = request.headers
+            body = self.call("UploadFile", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UploadFileResponse()
